"""
Google Spell Checker.
A simple multilingual Spell Checker using Google Text Completion.
"""
from .google_spell_checker import GoogleSpellChecker

__version__ = "0.2.1"
__author__ = 'Cahya Wirawan'
__credits__ = ''
